/*************************************************************/
/** MonochromeLib - monochrome graphic library for fx-9860G **/
/** MonochromeLib is free software                          **/
/**                                                         **/
/** @author Pierre "PierrotLL" Le Gall                      **/
/** @contact legallpierre89@gmail.com                       **/
/**                                                         **/
/** @file MonochromeLib.h                                   **/
/** Include header for MonochromeLib                        **/
/**                                                         **/
/** @date 05-02-2011                                        **/
/*************************************************************/

#ifndef MONOCHROMELIB
#define MONOCHROMELIB

/****************************************************/
/** uncomment #define of functions you want to use **/
/****************************************************/

//#define ML_PIXEL

//#define ML_HORIZONTAL_LINE
//#define ML_VERTICAL_LINE
#define ML_LINE

#define ML_RECTANGLE

//#define ML_POLYGONE
//#define ML_FILLED_POLYGONE

//#define ML_CIRCLE
//#define ML_FILLED_CIRCLE

//#define ML_ELLIPSE
//#define ML_FILLED_ELLIPSE

#define ML_BMP_OR
//#define ML_BMP_AND
//#define ML_BMP_XOR
//#define ML_BMP_OR_CL
//#define ML_BMP_AND_CL
//#define ML_BMP_XOR_CL

#define ML_BMP_8_OR
//#define ML_BMP_8_AND
#define ML_BMP_8_XOR
//#define ML_BMP_8_OR_CL
//#define ML_BMP_8_AND_CL
//#define ML_BMP_8_XOR_CL

//#define ML_BMP_16_OR
//#define ML_BMP_16_AND
//#define ML_BMP_16_XOR
//#define ML_BMP_16_OR_CL
//#define ML_BMP_16_AND_CL
//#define ML_BMP_16_XOR_CL



/**************************/
/** Functions prototypes **/
/**************************/

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {TRANSPARENT=-1, WHITE, BLACK, XOR} ML_Color;

#define sgn(x)	(x<0?-1:1)
#define rnd(x)	(x-(int)x<.5?(int)x:(int)x+1)

char* ML_vram_adress();

void ML_pixel(int x, int y, ML_Color);

void ML_horizontal_line(int y, int x1, int x2, ML_Color color);
void ML_vertical_line(int x, int y1, int y2, ML_Color color);
void ML_line(int x1, int y1, int x2, int y2, ML_Color color);

void ML_rectangle(int x1, int y1, int x2, int y2, int border_width, ML_Color border_color, ML_Color fill_color);

void ML_polygone(int *x, int *y, int nb_vertices, ML_Color color);
void ML_filled_polygone(int *x, int *y, int nb_vertices, ML_Color color);

void ML_circle(int x, int y, int radius, ML_Color color);
void ML_filled_circle(int x, int y, int radius, ML_Color color);

void ML_ellipse(int x, int y, int radius1, int radius2, ML_Color color);
void ML_ellipse_in_rect(int x1, int y1, int x2, int y2, ML_Color color);
void ML_filled_ellipse(int x, int y, int radius1, int radius2, ML_Color color);
void ML_filled_ellipse_in_rect(int x, int y, int radius1, int radius2, ML_Color color);


void ML_bmp_or(unsigned char *bmp, int x, int y, int width, int height);
void ML_bmp_and(unsigned char *bmp, int x, int y, int width, int height);
void ML_bmp_xor(unsigned char *bmp, int x, int y, int width, int height);
void ML_bmp_or_cl(unsigned char *bmp, int x, int y, int width, int height);
void ML_bmp_and_cl(unsigned char *bmp, int x, int y, int width, int height);
void ML_bmp_xor_cl(unsigned char *bmp, int x, int y, int width, int height);

void ML_bmp_8_or(unsigned char *bmp, int x, int y);
void ML_bmp_8_and(unsigned char *bmp, int x, int y);
void ML_bmp_8_xor(unsigned char *bmp, int x, int y);
void ML_bmp_8_or_cl(unsigned char *bmp, int x, int y);
void ML_bmp_8_and_cl(unsigned char *bmp, int x, int y);
void ML_bmp_8_xor_cl(unsigned char *bmp, int x, int y);

void ML_bmp_16_or(unsigned short *bmp, int x, int y);
void ML_bmp_16_and(unsigned short *bmp, int x, int y);
void ML_bmp_16_xor(unsigned short *bmp, int x, int y);
void ML_bmp_16_or_cl(unsigned short *bmp, int x, int y);
void ML_bmp_16_and_cl(unsigned short *bmp, int x, int y);
void ML_bmp_16_xor_cl(unsigned short *bmp, int x, int y);

#ifdef __cplusplus
}
#endif


#endif //MONOCHROMELIB
